@@ -3,7 +3,7 @@
 /*
     Subst      *d_subst_ptr     - external subst-structure
     Stack       d_empty_st      - empty
-    unsigned    d_empty_size    - 0
+    size_t      d_empty_size    - 0
     bool        d_keep_ws       - false
     Stack       d_media_st      - empty
     void       *d_media_ptr     - NULL
@@ -18,7 +18,7 @@ void lexer_construct(register Lexer *lp, Subst *sp)
     string_construct(&lp->d_text, 0);
     lp->d_subst_ptr = sp;
     stack_construct(&lp->d_empty_st, NULL);     /* stores values    */
-    stack_construct(&lp->d_media_st, l_media_destructor);
+    stack_construct(&lp->d_media_st, media_destructor);
     lp->d_maxdepth = args_option('n') ? args_optint('n') : 
                                                     DEFAULT_MAX_NESTED_FILES;
     lp->d_maxreplacements = 
